summaryrefslogtreecommitdiffstats
path: root/models/cards.js
diff options
context:
space:
mode:
Diffstat (limited to 'models/cards.js')
-rw-r--r--models/cards.js13
1 files changed, 8 insertions, 5 deletions
diff --git a/models/cards.js b/models/cards.js
index c5d9bf05..9b32e89a 100644
--- a/models/cards.js
+++ b/models/cards.js
@@ -69,7 +69,7 @@ Cards.attachSchema(new SimpleSchema({
type: String,
optional: true,
allowedValues: [
- 'green', 'yellow', 'orange', 'red', 'purple',
+ 'white', 'green', 'yellow', 'orange', 'red', 'purple',
'blue', 'sky', 'lime', 'pink', 'black',
'silver', 'peachpuff', 'crimson', 'plum', 'darkgreen',
'slateblue', 'magenta', 'gold', 'navy', 'gray',
@@ -1571,13 +1571,16 @@ if (Meteor.isServer) {
*
* @description Edit a card
*
* The color has to be chosen between `green`, `yellow`, `orange`, `red`,
* `purple`, `blue`, `sky`, `lime`, `pink`, `black`, `silver`, `peachpuff`,
* `crimson`, `plum`, `darkgreen`, `slateblue`, `magenta`, `gold`, `navy`,
* `gray`, `saddlebrown`, `paleturquoise`, `mistyrose`, `indigo`:
*
* <img src="/card-colors.png" width="40%" alt="Wekan card colors" />
*
+ * Note: setting the color to white has the same effect than removing it.
+ *
* @param {string} boardId the board ID of the card
* @param {string} list the list ID of the card
* @param {string} cardId the ID of the card
@@ -1571,13 +1571,16 @@ if (Meteor.isServer) {
* @description Edit a card
*
- * The color has to be chosen between `green`, `yellow`, `orange`, `red`,
- * `purple`, `blue`, `sky`, `lime`, `pink`, `black`, `silver`, `peachpuff`,
- * `crimson`, `plum`, `darkgreen`, `slateblue`, `magenta`, `gold`, `navy`,
- * `gray`, `saddlebrown`, `paleturquoise`, `mistyrose`, `indigo`:
+ * The color has to be chosen between `white`, `green`, `yellow`, `orange`,
+ * `red`, `purple`, `blue`, `sky`, `lime`, `pink`, `black`, `silver`,
+ * `peachpuff`, `crimson`, `plum`, `darkgreen`, `slateblue`, `magenta`,
+ * `gold`, `navy`, `gray`, `saddlebrown`, `paleturquoise`, `mistyrose`,
+ * `indigo`:
*
* <img src="/card-colors.png" width="40%" alt="Wekan card colors" />